@@ -40,7 +40,7 @@ namespace Banshee.Karaoke.Gui
     /// <summary>
     /// extra wrapper for Karaoke view so we can put some stuff around it if needed
     /// </summary>
-    public class KaraokePane : Notebook
+    public class KaraokePane : Notebook, Banshee.Gui.IDisableKeybindings
     {
         private KaraokeView view;
         private ContextPage context_page;
@@ -87,7 +87,6 @@ namespace Banshee.Karaoke.Gui
                         this.CurrentPage = this.PageNum (disconnected);
                     } else {
                         View.LoadLyrics (track);
-                        View.LoadStatusChanged += OnViewLoadStatusChanged;
                         timer.Change (0, 2000);
                         this.CurrentPage = this.PageNum (View);
                     }
@@ -99,14 +98,6 @@ namespace Banshee.Karaoke.Gui
             }
         }
 
-        void OnViewLoadStatusChanged (object sender, EventArgs e)
-        {
-            if (View.LoadStatus == Banshee.WebBrowser.OssiferLoadStatus.FirstVisuallyNonEmptyLayout) {
-                SetStyle ();
-                View.LoadStatusChanged -= OnViewLoadStatusChanged;
-            }
-        }
-
         private void TimerTimedOut (object o)
         {
             if (this.CurrentPage == this.PageNum (disconnected)) {
@@ -143,14 +134,6 @@ namespace Banshee.Karaoke.Gui
             View.ExecuteScript (String.Format ("window.postMessage({0},'http://youtubelyric.com');", ServiceManager.PlayerEngine.Position / 1000));
         }
 
-        private void SetStyle ()
-        {
-            if (this.CurrentPage == this.PageNum (disconnected)) {
-                return;
-            }
-            View.ExecuteScript ("if (document.getElementById ('lyricbox')) { document.getElementById ('lyricbox').style.fontSize='2.5em'; }");
-        }
-
         private void OnTrackChange (PlayerEventArgs args)
         {
             if (ServiceManager.PlayerEngine.CurrentState == PlayerState.Paused) {
